@@ -12,11 +12,23 @@
 #' @param ... Other arguments (See details)
 #' @return A tibble where each row corresponds to a rule. The columns are:
 #'   support, confidence, lift, lhs, rhs, n_conditions
-#' @details Optional named argument laplace(flag, default: TRUE) is supported.
-#'   This computes confidence with laplace correction as documented under
-#'   'Rulesets' here: [C5 doc](https://www.rulequest.com/see5-unix.html)
+#' @details
+#'
+#' Optional named arguments:
+#'
+#' \itemize{
+#'
+#' \item laplace(flag, default: TRUE) is supported. This computes confidence
+#' with laplace correction as documented under 'Rulesets' here: [C5
+#' doc](https://www.rulequest.com/see5-unix.html).
+#'
+#' \item language (string, default: "r"): language where the rules are parsable.
+#' The allowed options is one among: r, python, sql
+#'
+#' }
+#'
 #' @examples
-#' data("attrition", package = "rsample")
+#' data("attrition", package = "modeldata")
 #' attrition <- tibble::as_tibble(attrition)
 #' c5_model <- C50::C5.0(Attrition ~., data = attrition, rules = TRUE)
 #' summary(c5_model)
@@ -31,6 +43,22 @@ tidyRules.C5.0 <- function(object, ...){
     arguments[["laplace"]] = TRUE
   }
 
+  # asserts for 'language'
+  if(is.null(arguments[["language"]])){
+
+    arguments[["language"]] = "r"
+
+  } else {
+
+    assertthat::assert_that(assertthat::is.string(arguments[["language"]]))
+    arguments[["language"]] = stringr::str_to_lower(arguments[["language"]])
+    assertthat::assert_that(arguments[["language"]] %in% c("r"
+                                                           , "python"
+                                                           , "sql"
+                                                           )
+                            )
+  }
+
   # for magrittr dot ----
   . <- NULL
 
@@ -302,6 +330,15 @@ tidyRules.C5.0 <- function(object, ...){
       )
   }
 
+  # handle the rule parsable language
+  lang = arguments[["language"]]
+
+  if (lang == "python"){
+    res[["LHS"]] = ruleRToPython(res[["LHS"]])
+  } else if (lang == "sql"){
+    res[["LHS"]] = ruleRToSQL(res[["LHS"]])
+  }
+
   # return ----
   res <- tibble::rowid_to_column(res, "id")
   res <- res[, c("id", "LHS", "RHS", "support", "confidence"
